@@ -1,11 +1,11 @@
 package Template::Reverse::Converter::Regexp;
 
-# ABSTRACT: Convert parts to TT2 format simply
+# ABSTRACT: Convert parts to Regular Expression simply
 
 use Moo;
 use Scalar::Util qw(blessed);
 use utf8;
-our $VERSION = '0.140'; # VERSION
+our $VERSION = '0.141'; # VERSION
 
 sub Convert{
     my $self = shift;
@@ -44,17 +44,19 @@ __END__
 
 =head1 NAME
 
-Template::Reverse::Converter::Regexp - Convert parts to TT2 format simply
+Template::Reverse::Converter::Regexp - Convert parts to Regular Expression simply
 
 =head1 VERSION
 
-version 0.140
+version 0.141
 
 =head1 SYNOPSIS
 
-    package Template::Reverse::Converter::TT2;
-    my $tt2 = Template::Reverse::Converter::TT2->new;
-    $tt2->Convert([[['pretext'],['posttext']]]);
+    package Template::Reverse::Converter::Regexp;
+    my $tt2 = Template::Reverse::Converter::Regexp->new;
+    my $res = $tt2->Convert([[['pretext'],['posttext']]]);
+	"Some text" =~ /$res/;
+	print $1;
 
 =head1 AUTHOR
 
